import { ThirdwebSDK } from "../sdk";
import { Network } from "../types/index";
import { getPayer } from "./local-config";
import { KeypairSigner } from "@metaplex-foundation/js";
import { ThirdwebStorage } from "@thirdweb-dev/storage";

/**
 * Create an SDK instance using the local configuration generated by the Solana CLI
 *
 * @example
 * ```jsx
 * import { createThirdwebSDK } from "@thirdweb-dev/sdk/solana";
 *
 * // Select the network to create the SDK on
 * const sdk = createThirdwebSDK("devnet");
 * ```
 *
 * @public
 */
export function createThirdwebSDK(
  network: Network,
  storage: ThirdwebStorage = new ThirdwebStorage(),
): ThirdwebSDK {
  const payer = getPayer();
  const signer: KeypairSigner = {
    publicKey: payer.publicKey,
    secretKey: payer.secretKey,
  };
  const sdk = ThirdwebSDK.fromNetwork(network, storage);
  sdk.wallet.connect(signer);
  return sdk;
}
